@@ -4,8 +4,10 @@ markdown <- function(path = NULL, ..., strip_header = FALSE) {
 
   if (rmarkdown::pandoc_available("2.0")) {
     from <- "markdown_github-hard_line_breaks+smart+auto_identifiers"
-  } else {
+  } else if (rmarkdown::pandoc_available("1.12.3")) {
     from <- "markdown_github-hard_line_breaks"
+  } else {
+    stop("Pandoc not available", call. = FALSE)
   }
 
   rmarkdown::pandoc_convert(
